@@ -154,13 +154,8 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
     float perc = 0.0;
     float consumption = 0.0;
 
-    if (CommonStatic::CurrentSettings->PercType == Settings::SourceDefault ||
-        CommonStatic::CurrentSettings->PercType == Settings::SourceDrFrost){
-        qDebug() << "Getting temperature from omap34xx";
-        temperature = GetValue("/sys/devices/platform/omap34xx_temp/temp1_input");
-    }else if (CommonStatic::CurrentSettings->PercType == Settings::SourceBq27200){
+    if (CommonStatic::CurrentSettings->PercType == Settings::SourceBq27200){
         qDebug() << "Getting data from bq27200";
-        temperature = GetValue("/sys/class/power_supply/bq27200-0/temp");
         perc = GetValue("/sys/class/power_supply/bq27200-0/capacity");
         vcurrent = GetValue("/sys/class/power_supply/bq27200-0/voltage_now");
         //Fix voltage for kernel v47
@@ -168,14 +163,14 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
              vcurrent /= 1000;
     }
 
-    //Fix temperature for kernel v47
-    if (temperature > 100)
-        temperature /= 10.0;
+    temperature = GetTemperature();
     qDebug() << "Battery temperature: " << temperature;
     ui->lblTemp->setText(QString("%1C").arg(QString::number(temperature, 'f', 1)));
 
-    consumption = GetPowerConsumption();
-    qDebug() << "Power consumption: " << consumption << "mA";
+    if (CommonStatic::CurrentSettings->TimeLeft == Settings::TimeLeftConsumption){
+        consumption = GetPowerConsumption();
+        qDebug() << "Power consumption: " << consumption << "mA";
+    }
 
     qDebug() << "Getting data from omap34xx";
     QProcess* proc = new QProcess(this);
@@ -390,13 +385,18 @@ void MainWindow::ApplySettings()
         m_PbCharge->SetInsideMargins(8*CommonStatic::CurrentSettings->PercScale, 8*CommonStatic::CurrentSettings->PercScale, 16*CommonStatic::CurrentSettings->PercScale, 8*CommonStatic::CurrentSettings->PercScale);
     }else if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleStandard){
         m_PbCharge->SetBackgroundImage(QPixmap(":/images/grey.png"));
-        m_PbCharge->setFixedSize(QWIDGETSIZE_MAX, 48);
-        m_PbCharge->SetInsideMargins(0, 0, 0, 0);
+
+        QSize bkgSize(166, 98);
+        bkgSize.scale(166*CommonStatic::CurrentSettings->PercScale, 98*CommonStatic::CurrentSettings->PercScale, Qt::KeepAspectRatio);
+        bkgSize.setHeight(48);
+        m_PbCharge->setFixedSize(bkgSize);
 
         ui->lblPerc->setVisible(false);
         ui->frame->setVisible(true);
-        ui->frame->setFixedSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
-        ui->frame->setStyleSheet("");
+        qDebug() << "Percentage size:" << bkgSize.width() << "x" << bkgSize.height();
+        ui->frame->setFixedSize(bkgSize);
+        m_PbCharge->setFixedSize(bkgSize);
+        m_PbCharge->SetInsideMargins(0,0,0,0);
     }else if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleTextual){
         ui->lblPerc->setVisible(true);
         ui->frame->setVisible(false);
@@ -494,6 +494,18 @@ void MainWindow::DisplayStateChangedSlot(QString displayState)
     }
 }
 
+float MainWindow::GetTemperature()
+{
+    float temperature = GetValue("/sys/class/power_supply/bq27200-0/temp");
+    if (temperature == 0)
+        temperature = GetValue("/sys/devices/platform/omap34xx_temp/temp1_input");
+
+    //Fix temperature for kernel v47
+    if (temperature > 100)
+        temperature /= 10.0;
+    return temperature;
+}
+
 float MainWindow::GetPowerConsumption()
 {
     float res = 0.0;
