@@ -19,7 +19,7 @@
     <message>
         <location filename="mainwindow.ui" line="14"/>
         <source>MainWindow</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">MainWindow</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="33"/>
@@ -50,12 +50,12 @@
         <translation type="unfinished">Temp.:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="171"/>
+        <location filename="mainwindow.ui" line="162"/>
         <source>0.0 %</source>
         <translation type="unfinished">0.0 %</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="469"/>
+        <location filename="mainwindow.cpp" line="473"/>
         <source>%1% Charging</source>
         <translation type="unfinished">%1% In carica</translation>
     </message>
@@ -92,55 +92,65 @@
     </message>
     <message>
         <location filename="settingsdialog.ui" line="99"/>
+        <source>Time left:</source>
+        <translation type="unfinished">Tempo residuo:</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="109"/>
         <source>Show labels</source>
         <translation type="unfinished">Visualizza etichette</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="106"/>
+        <location filename="settingsdialog.ui" line="116"/>
         <source>Show charge</source>
         <translation type="unfinished">Visualizza carica</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="113"/>
+        <location filename="settingsdialog.ui" line="123"/>
         <source>Show voltage</source>
         <translation type="unfinished">Visualizza voltaggio</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="120"/>
+        <location filename="settingsdialog.ui" line="130"/>
         <source>Show time left</source>
         <translation type="unfinished">Visualizza tempo residuo</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="127"/>
+        <location filename="settingsdialog.ui" line="137"/>
         <source>Show temperature</source>
         <oldsource>Show Temp.</oldsource>
         <translation type="unfinished">Visualizza temperatura</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="134"/>
+        <location filename="settingsdialog.ui" line="144"/>
         <source>Opacity:</source>
         <translation type="unfinished">Trasparenza:</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="151"/>
+        <location filename="settingsdialog.ui" line="161"/>
         <source>About</source>
         <translation type="unfinished">About</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="175"/>
+        <location filename="settingsdialog.ui" line="185"/>
         <source>Save</source>
         <translation type="unfinished">Salva</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="36"/>
+        <location filename="settingsdialog.cpp" line="34"/>
         <source>Default</source>
         <translation type="unfinished">Default</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="37"/>
+        <location filename="settingsdialog.cpp" line="36"/>
         <source>bq27200</source>
         <translation type="unfinished">bq27200</translation>
     </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="37"/>
+        <source>dr_frost_dk</source>
+        <translation type="unfinished">dr_frost_dk</translation>
+    </message>
     <message>
         <location filename="settingsdialog.cpp" line="39"/>
         <source>Graphical</source>
@@ -157,12 +167,22 @@
         <translation type="unfinished">Testuale</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="85"/>
+        <location filename="settingsdialog.cpp" line="59"/>
+        <source>from power consumption</source>
+        <translation type="unfinished">basato sul consumo</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="60"/>
+        <source>from percentage change</source>
+        <translation type="unfinished">basato sulla variazione percentuale</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="95"/>
         <source>Opacity: %1</source>
         <translation type="unfinished">Trasparenza: %1</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="90"/>
+        <location filename="settingsdialog.cpp" line="100"/>
         <source>Percentage Size: %1%</source>
         <translation type="unfinished">Dimensione percentuale: %1%</translation>
     </message>
