@@ -32,6 +32,7 @@ Settings::Settings(QObject *parent) :
     ShowCharge = true;
     ShowRemaining = true;
     ShowTemp = true;
+    TimeLeft = TimeLeftConsumption;
 }
 
 QString Settings::GetConfigName()
@@ -59,6 +60,7 @@ bool Settings::Load()
     ShowVoltage = settings->value("ShowVoltage", true).toBool();
     ShowRemaining = settings->value("ShowRemaining", true).toBool();
     ShowTemp = settings->value("ShowTemp", true).toBool();
+    TimeLeft = (TimeLeftSource)settings->value("TimeLeft", TimeLeftConsumption).toInt();
 
     settings->endGroup();
     delete settings;
@@ -81,6 +83,7 @@ bool Settings::Save()
     settings->setValue("ShowVoltage", ShowVoltage);
     settings->setValue("ShowRemaining", ShowRemaining);
     settings->setValue("ShowTemp", ShowTemp);
+    settings->setValue("TimeLeft", TimeLeft);
 
     settings->endGroup();
     settings->sync();
